@@ -5,20 +5,20 @@ function(AA, isDAG = FALSE, eta=0.1){
     
     if(isDAG){
       
-      DD = solve(Ip - AA)
+      DD = solveCpp(Ip - AA)
       return(DD)
       
     }else{
       tmp = eigen(AA, symmetric=FALSE, only.values=TRUE)$values
       
       if( max(abs(tmp)) < 1-eta ){
-        DD = solve(Ip - AA)
+        DD = solveCpp(Ip - AA)
       }else{
         # This is consistent with the ref #2
         tmp = apply( abs(AA), 1, sum )
         tmp = matrix(tmp+eta, ncol=p, nrow=p, byrow=FALSE) 
         tmp = AA / tmp
-        DD = solve(Ip - tmp)
+        DD = solveCpp(Ip - tmp)
       }  
       
       return(DD)
